# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.1

import enum

import winrt.system
from winrt import _winrt_windows_phone_management_deployment

__all__ = [
    "EnterpriseEnrollmentStatus",
    "EnterpriseStatus",
    "Enterprise",
    "EnterpriseEnrollmentManager",
    "EnterpriseEnrollmentResult",
    "InstallationManager",
    "PackageInstallResult",
]

class EnterpriseEnrollmentStatus(enum.IntEnum):
    SUCCESS = 0
    CANCELLED_BY_USER = 1
    UNKNOWN_FAILURE = 2

class EnterpriseStatus(enum.IntEnum):
    ENROLLED = 0
    DISABLED = 1
    REVOKED = 2
    EXPIRED = 3

Enterprise = _winrt_windows_phone_management_deployment.Enterprise
EnterpriseEnrollmentManager = _winrt_windows_phone_management_deployment.EnterpriseEnrollmentManager
EnterpriseEnrollmentResult = _winrt_windows_phone_management_deployment.EnterpriseEnrollmentResult
InstallationManager = _winrt_windows_phone_management_deployment.InstallationManager
PackageInstallResult = _winrt_windows_phone_management_deployment.PackageInstallResult
